Intervention Strategies and Context Manager
===============================

This module provides inference mechanisms for intervening on concept-based models.

.. currentmodule:: torch_concepts.nn

Summary
-------

**Intervention Strategies**

.. autosummary::
   :toctree: generated
   :nosignatures:

   RewiringIntervention
   GroundTruthIntervention
   DoIntervention
   DistributionIntervention

**Intervention Context Manager**

.. autosummary::
   :toctree: generated
   :nosignatures:

   intervention


Class Documentation
-------------------

.. autoclass:: RewiringIntervention
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: GroundTruthIntervention
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: DoIntervention
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: DistributionIntervention
   :members:
   :undoc-members:
   :show-inheritance:


Function Documentation
----------------------

.. autofunction:: intervention
